class: Workflow
cwlVersion: cwl:draft-3
hints:
- class: DockerRequirement
  dockerImageId: bcbio/bcbio
  dockerPull: bcbio/bcbio
inputs:
- id: '#description'
  type:
    items: string
    type: array
- id: '#config__algorithm__validate'
  type:
    items: File
    type: array
- id: '#reference__fasta__base'
  type:
    items: File
    type: array
- id: '#config__algorithm__variantcaller'
  type:
    items: string
    type: array
- id: '#reference__rtg'
  type:
    items: File
    type: array
- id: '#metadata__batch'
  type:
    items: 'null'
    type: array
- id: '#config__algorithm__validate_regions'
  type:
    items: File
    type: array
- id: '#genome_build'
  type:
    items: string
    type: array
- id: '#metadata__phenotype'
  type:
    items: string
    type: array
- id: '#genome_resources__variation__dbsnp'
  type:
    items: File
    type: array
- id: '#genome_resources__variation__cosmic'
  type:
    items: File
    type: array
- id: '#analysis'
  type:
    items: string
    type: array
- id: '#config__algorithm__tools_on'
  type:
    items:
      items: string
      type: array
    type: array
- id: '#config__algorithm__variant_regions'
  type:
    items: File
    type: array
- id: '#align_bam'
  type:
    items: File
    type: array
- id: '#regions__callable'
  type:
    items: File
    type: array
- id: '#config__algorithm__callable_regions'
  type:
    items: File
    type: array
outputs:
- id: '#validate__summary'
  source: '#compare_to_rm.validate__summary'
  type:
  - File
  - 'null'
- id: '#validate__tp'
  secondaryFiles:
  - .tbi
  source: '#compare_to_rm.validate__tp'
  type:
  - File
  - 'null'
- id: '#validate__fp'
  secondaryFiles:
  - .tbi
  source: '#compare_to_rm.validate__fp'
  type:
  - File
  - 'null'
- id: '#validate__fn'
  secondaryFiles:
  - .tbi
  source: '#compare_to_rm.validate__fn'
  type:
  - File
  - 'null'
- id: '#vrn_file'
  secondaryFiles:
  - .tbi
  source: '#postprocess_variants.vrn_file'
  type: File
requirements:
- class: EnvVarRequirement
  envDef:
  - envName: MPLCONFIGDIR
    envValue: .
- class: ScatterFeatureRequirement
- class: StepInputExpressionRequirement
- class: SubworkflowFeatureRequirement
- class: InlineJavascriptRequirement
steps:
- id: '#get_parallel_regions'
  inputs:
  - id: '#get_parallel_regions.description'
    source: '#description'
  - id: '#get_parallel_regions.config__algorithm__validate'
    source: '#config__algorithm__validate'
  - id: '#get_parallel_regions.reference__fasta__base'
    source: '#reference__fasta__base'
  - id: '#get_parallel_regions.config__algorithm__variantcaller'
    source: '#config__algorithm__variantcaller'
  - id: '#get_parallel_regions.reference__rtg'
    source: '#reference__rtg'
  - id: '#get_parallel_regions.metadata__batch'
    source: '#metadata__batch'
  - id: '#get_parallel_regions.config__algorithm__validate_regions'
    source: '#config__algorithm__validate_regions'
  - id: '#get_parallel_regions.genome_build'
    source: '#genome_build'
  - id: '#get_parallel_regions.metadata__phenotype'
    source: '#metadata__phenotype'
  - id: '#get_parallel_regions.genome_resources__variation__dbsnp'
    source: '#genome_resources__variation__dbsnp'
  - id: '#get_parallel_regions.genome_resources__variation__cosmic'
    source: '#genome_resources__variation__cosmic'
  - id: '#get_parallel_regions.analysis'
    source: '#analysis'
  - id: '#get_parallel_regions.config__algorithm__tools_on'
    source: '#config__algorithm__tools_on'
  - id: '#get_parallel_regions.config__algorithm__variant_regions'
    source: '#config__algorithm__variant_regions'
  - id: '#get_parallel_regions.align_bam'
    source: '#align_bam'
  - id: '#get_parallel_regions.regions__callable'
    source: '#regions__callable'
  - id: '#get_parallel_regions.config__algorithm__callable_regions'
    source: '#config__algorithm__callable_regions'
  outputs:
  - id: '#get_parallel_regions.region'
  run: steps/get_parallel_regions.cwl
- id: '#variantcall_batch_region'
  inputs:
  - id: '#variantcall_batch_region.description'
    source: '#description'
  - id: '#variantcall_batch_region.config__algorithm__validate'
    source: '#config__algorithm__validate'
  - id: '#variantcall_batch_region.reference__fasta__base'
    source: '#reference__fasta__base'
  - id: '#variantcall_batch_region.config__algorithm__variantcaller'
    source: '#config__algorithm__variantcaller'
  - id: '#variantcall_batch_region.reference__rtg'
    source: '#reference__rtg'
  - id: '#variantcall_batch_region.metadata__batch'
    source: '#metadata__batch'
  - id: '#variantcall_batch_region.config__algorithm__validate_regions'
    source: '#config__algorithm__validate_regions'
  - id: '#variantcall_batch_region.genome_build'
    source: '#genome_build'
  - id: '#variantcall_batch_region.metadata__phenotype'
    source: '#metadata__phenotype'
  - id: '#variantcall_batch_region.genome_resources__variation__dbsnp'
    source: '#genome_resources__variation__dbsnp'
  - id: '#variantcall_batch_region.genome_resources__variation__cosmic'
    source: '#genome_resources__variation__cosmic'
  - id: '#variantcall_batch_region.analysis'
    source: '#analysis'
  - id: '#variantcall_batch_region.config__algorithm__tools_on'
    source: '#config__algorithm__tools_on'
  - id: '#variantcall_batch_region.config__algorithm__variant_regions'
    source: '#config__algorithm__variant_regions'
  - id: '#variantcall_batch_region.align_bam'
    source: '#align_bam'
  - id: '#variantcall_batch_region.regions__callable'
    source: '#regions__callable'
  - id: '#variantcall_batch_region.config__algorithm__callable_regions'
    source: '#config__algorithm__callable_regions'
  - id: '#variantcall_batch_region.region'
    source: '#get_parallel_regions.region'
  outputs:
  - id: '#variantcall_batch_region.vrn_file_region'
  - id: '#variantcall_batch_region.region'
  run: steps/variantcall_batch_region.cwl
  scatter:
  - '#variantcall_batch_region.region'
  scatterMethod: dotproduct
- id: '#concat_batch_variantcalls'
  inputs:
  - id: '#concat_batch_variantcalls.description'
    source: '#description'
  - id: '#concat_batch_variantcalls.config__algorithm__validate'
    source: '#config__algorithm__validate'
  - id: '#concat_batch_variantcalls.reference__fasta__base'
    source: '#reference__fasta__base'
  - id: '#concat_batch_variantcalls.config__algorithm__variantcaller'
    source: '#config__algorithm__variantcaller'
  - id: '#concat_batch_variantcalls.reference__rtg'
    source: '#reference__rtg'
  - id: '#concat_batch_variantcalls.metadata__batch'
    source: '#metadata__batch'
  - id: '#concat_batch_variantcalls.config__algorithm__validate_regions'
    source: '#config__algorithm__validate_regions'
  - id: '#concat_batch_variantcalls.genome_build'
    source: '#genome_build'
  - id: '#concat_batch_variantcalls.metadata__phenotype'
    source: '#metadata__phenotype'
  - id: '#concat_batch_variantcalls.genome_resources__variation__dbsnp'
    source: '#genome_resources__variation__dbsnp'
  - id: '#concat_batch_variantcalls.genome_resources__variation__cosmic'
    source: '#genome_resources__variation__cosmic'
  - id: '#concat_batch_variantcalls.analysis'
    source: '#analysis'
  - id: '#concat_batch_variantcalls.config__algorithm__tools_on'
    source: '#config__algorithm__tools_on'
  - id: '#concat_batch_variantcalls.config__algorithm__variant_regions'
    source: '#config__algorithm__variant_regions'
  - id: '#concat_batch_variantcalls.align_bam'
    source: '#align_bam'
  - id: '#concat_batch_variantcalls.regions__callable'
    source: '#regions__callable'
  - id: '#concat_batch_variantcalls.config__algorithm__callable_regions'
    source: '#config__algorithm__callable_regions'
  - id: '#concat_batch_variantcalls.region'
    source: '#variantcall_batch_region.region'
  - id: '#concat_batch_variantcalls.vrn_file_region'
    source: '#variantcall_batch_region.vrn_file_region'
  outputs:
  - id: '#concat_batch_variantcalls.vrn_file'
  run: steps/concat_batch_variantcalls.cwl
- id: '#postprocess_variants'
  inputs:
  - id: '#postprocess_variants.description'
    source: '#description'
  - id: '#postprocess_variants.config__algorithm__validate'
    source: '#config__algorithm__validate'
  - id: '#postprocess_variants.reference__fasta__base'
    source: '#reference__fasta__base'
  - id: '#postprocess_variants.config__algorithm__variantcaller'
    source: '#config__algorithm__variantcaller'
  - id: '#postprocess_variants.reference__rtg'
    source: '#reference__rtg'
  - id: '#postprocess_variants.metadata__batch'
    source: '#metadata__batch'
  - id: '#postprocess_variants.config__algorithm__validate_regions'
    source: '#config__algorithm__validate_regions'
  - id: '#postprocess_variants.genome_build'
    source: '#genome_build'
  - id: '#postprocess_variants.metadata__phenotype'
    source: '#metadata__phenotype'
  - id: '#postprocess_variants.genome_resources__variation__dbsnp'
    source: '#genome_resources__variation__dbsnp'
  - id: '#postprocess_variants.genome_resources__variation__cosmic'
    source: '#genome_resources__variation__cosmic'
  - id: '#postprocess_variants.analysis'
    source: '#analysis'
  - id: '#postprocess_variants.config__algorithm__tools_on'
    source: '#config__algorithm__tools_on'
  - id: '#postprocess_variants.config__algorithm__variant_regions'
    source: '#config__algorithm__variant_regions'
  - id: '#postprocess_variants.align_bam'
    source: '#align_bam'
  - id: '#postprocess_variants.regions__callable'
    source: '#regions__callable'
  - id: '#postprocess_variants.config__algorithm__callable_regions'
    source: '#config__algorithm__callable_regions'
  - id: '#postprocess_variants.vrn_file'
    source: '#concat_batch_variantcalls.vrn_file'
  outputs:
  - id: '#postprocess_variants.vrn_file'
  run: steps/postprocess_variants.cwl
- id: '#compare_to_rm'
  inputs:
  - id: '#compare_to_rm.description'
    source: '#description'
  - id: '#compare_to_rm.config__algorithm__validate'
    source: '#config__algorithm__validate'
  - id: '#compare_to_rm.reference__fasta__base'
    source: '#reference__fasta__base'
  - id: '#compare_to_rm.config__algorithm__variantcaller'
    source: '#config__algorithm__variantcaller'
  - id: '#compare_to_rm.reference__rtg'
    source: '#reference__rtg'
  - id: '#compare_to_rm.metadata__batch'
    source: '#metadata__batch'
  - id: '#compare_to_rm.config__algorithm__validate_regions'
    source: '#config__algorithm__validate_regions'
  - id: '#compare_to_rm.genome_build'
    source: '#genome_build'
  - id: '#compare_to_rm.metadata__phenotype'
    source: '#metadata__phenotype'
  - id: '#compare_to_rm.genome_resources__variation__dbsnp'
    source: '#genome_resources__variation__dbsnp'
  - id: '#compare_to_rm.genome_resources__variation__cosmic'
    source: '#genome_resources__variation__cosmic'
  - id: '#compare_to_rm.analysis'
    source: '#analysis'
  - id: '#compare_to_rm.config__algorithm__tools_on'
    source: '#config__algorithm__tools_on'
  - id: '#compare_to_rm.config__algorithm__variant_regions'
    source: '#config__algorithm__variant_regions'
  - id: '#compare_to_rm.align_bam'
    source: '#align_bam'
  - id: '#compare_to_rm.regions__callable'
    source: '#regions__callable'
  - id: '#compare_to_rm.config__algorithm__callable_regions'
    source: '#config__algorithm__callable_regions'
  - id: '#compare_to_rm.vrn_file'
    source: '#postprocess_variants.vrn_file'
  outputs:
  - id: '#compare_to_rm.validate__summary'
  - id: '#compare_to_rm.validate__tp'
  - id: '#compare_to_rm.validate__fp'
  - id: '#compare_to_rm.validate__fn'
  run: steps/compare_to_rm.cwl
